==> ae2-pattern-encoding-access-terminal-1.20.1-1.0.0-sources.jar: yuuki1293/ae2peat/wireless/WPEATMenu.java <==
package yuuki1293.ae2peat.wireless;

import appeng.api.storage.ITerminalHost;
import appeng.api.upgrades.IUpgradeInventory;
import appeng.menu.SlotSemantics;
import appeng.menu.ToolboxMenu;
import appeng.menu.implementations.MenuTypeBuilder;
import appeng.menu.slot.RestrictedInputSlot;
import de.mari_023.ae2wtlib.AE2wtlibSlotSemantics;
import de.mari_023.ae2wtlib.wct.WCTMenuHost;
import de.mari_023.ae2wtlib.wut.ItemWUT;
import net.minecraft.world.entity.player.Inventory;
import net.minecraft.world.inventory.MenuType;
import yuuki1293.ae2peat.definisions.PEATIds;
import yuuki1293.ae2peat.menu.PatternEncodingAccessTermMenu;

public class WPEATMenu extends PatternEncodingAccessTermMenu {
    public static final MenuType<WPEATMenu> TYPE = MenuTypeBuilder.create(WPEATMenu::new, WPEATMenuHost.class)
            .build(PEATIds.WIRELESS_PATTERN_ENCODING_ACCESS_TERMINAL);

    private final WPEATMenuHost wpeatMenuHost;
    private final ToolboxMenu toolboxMenu;

    public WPEATMenu(int id, Inventory ip, WPEATMenuHost anchor) {
        super(TYPE, id, ip, anchor, true);
        wpeatMenuHost = anchor;
        toolboxMenu = new ToolboxMenu(this);

        IUpgradeInventory upgrades = wpeatMenuHost.getUpgrades();
        for (int i = 0; i < upgrades.size(); i++) {
            var slot = new RestrictedInputSlot(RestrictedInputSlot.PlacableItemType.UPGRADES, upgrades, i);
            slot.setNotDraggable();
            addSlot(slot, SlotSemantics.UPGRADE);
        }
        addSlot(
                new RestrictedInputSlot(
                        RestrictedInputSlot.PlacableItemType.QE_SINGULARITY,
                        wpeatMenuHost.getSubInventory(WCTMenuHost.INV_SINGULARITY),
                        0),
                AE2wtlibSlotSemantics.SINGULARITY);
    }

    @Override
    public void broadcastChanges() {
        toolboxMenu.tick();
        super.broadcastChanges();
    }

    public boolean isWUT() {
        return wpeatMenuHost.getItemStack().getItem() instanceof ItemWUT;
    }

    public ITerminalHost getHost() {
        return wpeatMenuHost;
    }

    public ToolboxMenu getToolbox() {
        return toolboxMenu;
    }
}

==> ae2-pattern-encoding-access-terminal-1.21.1-1.1.0-rc.3-sources.jar: yuuki1293/ae2peat/wireless/WPEATMenu.java <==
package yuuki1293.ae2peat.wireless;

import appeng.api.storage.ITerminalHost;
import appeng.api.upgrades.IUpgradeInventory;
import appeng.menu.SlotSemantics;
import appeng.menu.ToolboxMenu;
import appeng.menu.implementations.MenuTypeBuilder;
import appeng.menu.slot.RestrictedInputSlot;
import de.mari_023.ae2wtlib.api.terminal.ItemWUT;
import de.mari_023.ae2wtlib.api.terminal.WTMenuHost;
import net.minecraft.world.entity.player.Inventory;
import net.minecraft.world.inventory.MenuType;
import yuuki1293.ae2peat.AE2PEAT;
import yuuki1293.ae2peat.definisions.PEATIds;
import yuuki1293.ae2peat.menu.PatternEncodingAccessTermMenu;

public class WPEATMenu extends PatternEncodingAccessTermMenu {
    public static final MenuType<WPEATMenu> TYPE = MenuTypeBuilder.create(WPEATMenu::new, WPEATMenuHost.class)
            .buildUnregistered(AE2PEAT.makeId(PEATIds.WIRELESS_PATTERN_ENCODING_ACCESS_TERMINAL));

    private final WPEATMenuHost wpeatMenuHost;
    private final ToolboxMenu toolboxMenu;

    public WPEATMenu(int id, Inventory ip, WPEATMenuHost anchor) {
        super(TYPE, id, ip, anchor, true);
        wpeatMenuHost = anchor;
        toolboxMenu = new ToolboxMenu(this);
        IUpgradeInventory upgrades = this.wpeatMenuHost.getUpgrades();

        for (int i = 0; i < upgrades.size(); ++i) {
            RestrictedInputSlot slot =
                    new RestrictedInputSlot(RestrictedInputSlot.PlacableItemType.UPGRADES, upgrades, i);
            slot.setNotDraggable();
            this.addSlot(slot, SlotSemantics.UPGRADE);
        }

        this.addSlot(
                new RestrictedInputSlot(
                        RestrictedInputSlot.PlacableItemType.QE_SINGULARITY,
                        this.wpeatMenuHost.getSubInventory(WTMenuHost.INV_SINGULARITY),
                        0),
                de.mari_023.ae2wtlib.api.gui.AE2wtlibSlotSemantics.SINGULARITY);
    }

    @Override
    public void broadcastChanges() {
        toolboxMenu.tick();
        super.broadcastChanges();
    }

    public boolean isWUT() {
        return this.wpeatMenuHost.getItemStack().getItem() instanceof ItemWUT;
    }

    public ITerminalHost getHost() {
        return wpeatMenuHost;
    }

    public ToolboxMenu getToolbox() {
        return toolboxMenu;
    }
}
